@@ -2,7 +2,7 @@ package Net::DNS::RR::CDNSKEY;
 
 use strict;
 use warnings;
-our $VERSION = (qw$Id: CDNSKEY.pm 1857 2021-12-07 13:38:02Z willem $)[2];
+our $VERSION = (qw$Id: CDNSKEY.pm 1909 2023-03-23 11:36:16Z willem $)[2];
 
 use base qw(Net::DNS::RR::DNSKEY);
 
@@ -16,22 +16,23 @@ Net::DNS::RR::CDNSKEY - DNS CDNSKEY resource record
 use integer;
 
 
+sub _format_rdata {			## format rdata portion of RR string.
+	my $self = shift;
+
+	return $self->SUPER::_format_rdata() if $self->algorithm;
+	return my @rdata = @{$self}{qw(flags protocol algorithm)}, "AA==";
+}
+
+
 sub algorithm {
 	my ( $self, $arg ) = @_;
 	return $self->SUPER::algorithm($arg) if $arg;
 	return $self->SUPER::algorithm() unless defined $arg;
-	@{$self}{qw(flags protocol algorithm)} = ( 0, 3, 0 );
+	@{$self}{qw(flags protocol algorithm keybin)} = ( 0, 3, 0, chr(0) );
 	return;
 }
 
 
-sub key {
-	my $self = shift;
-	return $self->SUPER::key(@_) unless defined( $_[0] ) && length( $_[0] ) < 2;
-	return $self->SUPER::keybin( $_[0] ? '' : chr(0) );
-}
-
-
 1;
 __END__
 
@@ -91,6 +92,8 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, L<Net::DNS::RR::DNSKEY>, RFC7344, RFC8078(erratum 5049)
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<Net::DNS::RR::DNSKEY>
+L<RFC7344|https://tools.ietf.org/html/rfc7344>
 
 =cut
