@@ -2,7 +2,7 @@ package Net::DNS::RR::NULL;
 
 use strict;
 use warnings;
-our $VERSION = (qw$Id: NULL.pm 1814 2020-10-14 21:49:16Z willem $)[2];
+our $VERSION = (qw$Id: NULL.pm 1972 2024-04-21 08:13:19Z willem $)[2];
 
 use base qw(Net::DNS::RR);
 
@@ -64,7 +64,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
@@ -81,6 +81,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC1035 Section 3.3.10
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<RFC1035(3.3.10)|https://iana.org/go/rfc1035#section-3.3.10>
 
 =cut
